# Generated by Django 3.2.12 on 2022-03-31 11:10

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("fcm_django", "0009_alter_fcmdevice_user"),
    ]

    operations = [
        migrations.AlterField(
            model_name="fcmdevice",
            name="registration_id",
            field=models.TextField(
                verbose_name="Registration token",
                unique=True,
            ),
        ),
    ]
